@@ -3,12 +3,12 @@ package Specio::Constraint::Enum;
 use strict;
 use warnings;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
-use Clone ();
 use Role::Tiny::With;
 use Scalar::Util qw( refaddr );
 use Specio::Library::Builtins;
+use Specio qw( _clone );
 use Specio::OO;
 
 use Specio::Constraint::Role::Interface;
@@ -16,7 +16,7 @@ with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = _clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( parent _inline_generator )) {
@@ -86,7 +86,7 @@ Specio::Constraint::Enum - A class for constraints which require a string matchi
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 SYNOPSIS
 
