@@ -3,11 +3,11 @@ package Specio::Constraint::Intersection;
 use strict;
 use warnings;
 
-our $VERSION = '0.50';
+our $VERSION = '0.52';
 
-use Clone ();
 use List::Util 1.33 qw( all );
 use Role::Tiny::With;
+use Specio qw( _clone );
 use Specio::OO;
 
 use Specio::Constraint::Role::Interface;
@@ -15,7 +15,7 @@ with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = _clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( _constraint _inline_generator )) {
@@ -133,7 +133,7 @@ Specio::Constraint::Intersection - A class for intersection constraints
 
 =head1 VERSION
 
-version 0.50
+version 0.52
 
 =head1 SYNOPSIS
 
